/**
 * @file
 * JS extensions for quote_plus_js module.
 */

// Create our own namespace and specialized functions.
Drupal.quotePlusJs = {

  /**
   * Make an Ajax request to the module callbacks.
   */
  ajaxRequest: function(type, caller, appendContent) {
    var cid = Drupal.quotePlusJs.extractId(caller, 'cid');
    var url = Drupal.quotePlusJs.callbackUrl(type) + '/' + Drupal.quotePlusJs.extractId(caller, 'nid') + '/' + cid;
    $.ajax({
      type: 'POST',
      dataType: 'json',
      url: Drupal.settings.basePath + url,
      success: function(data) {
        Drupal.quotePlusJs.updateForm(cid, data, appendContent);
      }
    });
  },

  // Ajax callback base paths:
  callbackUrl: function (type) {
    return 'js/quote_plus_js/' + type;
  },

  /**
   * Extract the nid/cid from a link's CSS class.
   */
  extractId: function(caller, type) {
    var ret = '';
    var regex = new RegExp('\\b(reply|(multi)?quote)-' + type + '-([0-9]+)');
    var ids = caller.attr('class').match(regex);
    if (ids) {
      ret = ids[3];
    }
    return ret;
  },

  /**
   * Change form data on successful Ajax operation.
   *
   * This callback processes instant reply and instant quote results.
   * It changes the comment form's subject and body to the data
   * retrieved from the server callback.
   *
   * It also changes the form's "referer" field which will help
   * to properly indicate which content the new comment refers to.
   * This is important as the comment form, when residing on the node page
   * below the node and it's comments, by default considers comments always
   * referring to the node itself whyle the user may have clicked "reply to
   * comment".
   */
  updateForm: function(cid, data, appendContent) {
    if (data) {
      if (data.subject != '') {
        $('input#edit-subject').val(data.subject);
      }
      if (appendContent) {
        data.content = $('textarea#edit-comment').val() + '\n' + data.content;
      }
      $('textarea#edit-comment').val(data.content).scrollTop(
        $("textarea#edit-comment").attr("scrollHeight")
      ).focus();
    }
    $('input#edit-pid').val(cid);
  }
}

Drupal.behaviors.quotePlusJs = function(context) {

  // Create dynamic links and attach events. This all will only work
  // if we have the comment form residing on the same page, of course.
  if ($('form#comment-form').length > 0) {

    // Instant reply links.
    if (Drupal.settings.quotePlusJs.instantReplies) {
      $("div.links a.reply", context).each(function() {
        $(this).click(function(event) {
          Drupal.quotePlusJs.ajaxRequest('reply', $(this));
          event.preventDefault();
        });
      });
    }

    // Instant quote links.
    if (Drupal.settings.quotePlusJs.instantQuotes) {
      $("div.links a.quote").each(function() {
        $(this).click(function(event) {
          Drupal.quotePlusJs.ajaxRequest('quote', $(this));
          event.preventDefault();
        });
      });
    }

    // Multiquote links. Transform the disabled HTML-spans into working links.
    if (Drupal.settings.quotePlusJs.multiquotes) {
      $("div.links span.multiquote").each(function() {
        $(this).after(
          '<a href="#" title="'
            + Drupal.t('Append a quote of this to your reply.')
            + '" class="' + $(this).attr("class") + '">'
            + $(this).html() + '</a>'
        ).remove();
      });
      $("div.links a.multiquote").each(function() {
        $(this).click(function(event) {
          Drupal.quotePlusJs.ajaxRequest('quote', $(this), true);
          event.preventDefault();
        });
      });
    }

  }
}
